import { HTMLChakraProps, ThemingProps } from "@teste-ui/system";
import { UseNumberInputProps } from "./use-number-input";
export declare const useNumberInputStyles: () => import("@teste-ui/utils").Dict<import("@teste-ui/system").CSSObject>;
interface InputOptions {
    /**
     * The border color when the input is focused. Use color keys in `theme.colors`
     * @example
     * focusBorderColor = "blue.500"
     */
    focusBorderColor?: string;
    /**
     * The border color when the input is invalid. Use color keys in `theme.colors`
     * @example
     * errorBorderColor = "red.500"
     */
    errorBorderColor?: string;
}
export interface NumberInputProps extends UseNumberInputProps, ThemingProps<"NumberInput">, InputOptions, Omit<HTMLChakraProps<"div">, keyof UseNumberInputProps> {
}
/**
 * NumberInput
 *
 * React component that provides context and logic to all
 * number input sub-components.
 *
 * It renders a `div` by default.
 *
 * @see Docs http://teste-ui.com/numberinput
 */
export declare const NumberInput: import("@teste-ui/system").ComponentWithAs<"div", NumberInputProps>;
export interface NumberInputStepperProps extends HTMLChakraProps<"div"> {
}
/**
 * NumberInputStepper
 *
 * React component used to group the increment and decrement
 * button spinners.
 *
 * It renders a `div` by default.
 *
 * @see Docs http://teste-ui.com/components/number-input
 */
export declare const NumberInputStepper: import("@teste-ui/system").ComponentWithAs<"div", NumberInputStepperProps>;
export interface NumberInputFieldProps extends HTMLChakraProps<"input"> {
}
/**
 * NumberInputField
 *
 * React component that represents the actual `input` field
 * where users can type to edit numeric values.
 *
 * It renders an `input` by default and ensures only numeric
 * values can be typed.
 *
 * @see Docs http://teste-ui.com/numberinput
 */
export declare const NumberInputField: import("@teste-ui/system").ComponentWithAs<"input", NumberInputFieldProps>;
export declare const StyledStepper: import("@teste-ui/system").ChakraComponent<"div", {}>;
export interface NumberDecrementStepperProps extends HTMLChakraProps<"div"> {
}
/**
 * NumberDecrementStepper
 *
 * React component used to decrement the number input's value
 *
 * It renders a `div` with `role=button` by default
 */
export declare const NumberDecrementStepper: import("@teste-ui/system").ComponentWithAs<"div", NumberDecrementStepperProps>;
export interface NumberIncrementStepperProps extends HTMLChakraProps<"div"> {
}
/**
 * NumberIncrementStepper
 *
 * React component used to increment the number input's value
 *
 * It renders a `div` with `role=button` by default
 */
export declare const NumberIncrementStepper: import("@teste-ui/system").ComponentWithAs<"div", NumberIncrementStepperProps>;
export {};
//# sourceMappingURL=number-input.d.ts.map